@@ -1,5 +1,6 @@
 import math
 from abc import ABC, abstractmethod
+from collections.abc import Iterable
 from functools import lru_cache, partial
 from itertools import combinations
 from typing import Callable
@@ -126,7 +127,7 @@ class ShapExplainer(Explainer):
         """Create single-row background dataset"""
         if isinstance(x, pd.DataFrame):
             return self._create_background_data_from_full_frame(x)
-        else:
+        elif isinstance(x, Iterable):
             first = drop_nas_from_batch(next(x), next(y))
             return self._created_batched_background_data(first=first, x=x, y=y)
 
@@ -153,10 +154,13 @@ class ShapExplainer(Explainer):
     def _create_background_data_from_full_frame(x: pd.DataFrame):
         background = {}
         for col in x.columns:
-            if pd.api.types.is_numeric_dtype(x[col]):
+            if pd.api.types.is_numeric_dtype(x[col]) and not pd.api.types.is_bool_dtype(
+                x[col]
+            ):
                 background[col] = [x[col].mean()]
             else:
-                background[col] = [x[col].mode(dropna=True).values[0]]
+                mode = x[col].mode(dropna=True).values
+                background[col] = [mode[0]] if mode.size > 0 else [None]
         x_background = pd.DataFrame(background, columns=x.columns).astype(x.dtypes)
         return x_background
 
@@ -206,8 +210,8 @@ class ShapExplainer(Explainer):
         x_empty = self._map_features(empty_coalition, row)
         x_full = self._map_features(full_coalition, row)
 
-        y_empty = np.float(self.func(x_empty))
-        y_full = np.float(self.func(x_full))
+        y_empty = float(self.func(x_empty))
+        y_full = float(self.func(x_full))
 
         if self.n_col == 1:
             # We have two constraints and two unknowns
@@ -275,7 +279,7 @@ class ShapExplainer(Explainer):
         for i, col in enumerate(x_mapped.columns):
             inside = coalitions_array[:, i]
             x_mapped[col].where(
-                cond=inside, other=self.x[col].values, inplace=True, try_cast=True
+                cond=inside, other=self.x[col].values[0], inplace=True, try_cast=True
             )
         return x_mapped
 
